# Generated by Django 2.1.14 on 2020-02-04 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0039_merge_20200131_1022'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='estimated_hours',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True),
        ),
        migrations.AlterField(
            model_name='task',
            name='remaining_hours',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True),
        ),
    ]



# Generated by Django 2.1.14 on 2019-12-10 15:18

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0033_merge_20191204_1022'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='priority',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Priority'),
        ),
    ]
